@@ -38,6 +38,13 @@ class StationStatusTestCase(unittest.TestCase):
         status = StationStatus(self.velib_id)
         self.assertTrue(isinstance(status.get_status(), dict))
 
+    def test_GetStatusExpatError(self):
+        status = StationStatus(42005)
+        status.xml_url = '.'
+        self.assertTrue(isinstance(status.get_status(), dict))
+        self.assertEquals(status.free, 0)
+
+
 suite = unittest.TestLoader().loadTestsFromTestCase(StationStatusTestCase)
 
     
